[Bf-blender-cvs] [c9acc5faad0] master: Fix T68597: GPencil Dope Sheet can fail to display active GP object

Antonioya noreply at git.blender.org
Wed Aug 14 10:31:55 CEST 2019


Commit: c9acc5faad08422e07be59fc160a028a45b7440c
Author: Antonioya
Date:   Wed Aug 14 10:29:21 2019 +0200
Branches: master
https://developer.blender.org/rBc9acc5faad08422e07be59fc160a028a45b7440c

Fix T68597: GPencil Dope Sheet can fail to display active GP object

Now, the dopesheet is activated if the object is in any Edition mode.

===================================================================

M	source/blender/editors/animation/anim_filter.c

===================================================================

diff --git a/source/blender/editors/animation/anim_filter.c b/source/blender/editors/animation/anim_filter.c
index 625a52fc800..a78a63f1347 100644
--- a/source/blender/editors/animation/anim_filter.c
+++ b/source/blender/editors/animation/anim_filter.c
@@ -1829,13 +1829,13 @@ static size_t animdata_filter_gpencil(bAnimContext *ac,
           }
         }
 
-        /* check selection and object type filters */
-        if ((ads->filterflag & ADS_FILTER_ONLYSEL) &&
-            !((base->flag & BASE_SELECTED) /*|| (base == scene->basact)*/)) {
-          /* only selected should be shown */
-          continue;
+        /* check selection and object type filters only for Object mode */
+        if (ob->mode == OB_MODE_OBJECT) {
+          if ((ads->filterflag & ADS_FILTER_ONLYSEL) && !((base->flag & BASE_SELECTED))) {
+            /* only selected should be shown */
+            continue;
+          }
         }
-
         /* check if object belongs to the filtering group if option to filter
          * objects by the grouped status is on
          * - used to ease the process of doing multiple-character choreographies



More information about the Bf-blender-cvs mailing list